@@ -5,7 +5,7 @@ class Movement:
 	b_counter = 0
 	p_counter = 0
 
-	loop = 1
+	loop = 0
 	default_bpm = 120
 	default_wildness = 0.5
 	default_key = 'C'
@@ -37,7 +37,7 @@ class Movement:
 		"""Prepares and returns the next block in the movement.\
 Returns None if there is no next block."""
 		if len(self.blocks) > 0:
-			if self.loop > 0:
+			if self.loop >= 0:
 				r = self.get_block()
 				r.progressions = self.get_progression()
 				self.b_counter += 1
