@@ -11,6 +11,7 @@ from mingus.core import chords
 from sys import argv
 from os import path
 import Musicians
+import Progressions
 
 import Options
 from mingus.core import diatonic
@@ -272,7 +273,8 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		for x in Options.get_available_blocks():
 			self.ui.blockcombo.addItem(x)
 		for x in Options.get_available_progressions():
-			self.ui.progressioncombo.addItem(x)
+			prog = Options.progression_to_string(getattr(Progressions, x))
+			self.ui.progressioncombo.addItem("%s %s" % (x, prog))
 		for x in Options.get_available_movements():
 			self.ui.movement.addItem(x)
 		for x in [1, 2, 4, 8, 16, 32, 64, 128]:
@@ -536,9 +538,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if o.progression != "":
 			prog = o.progression.split(",")
 			for p in prog:
-				if p in Options.get_available_progressions():
+				try:
+					r = Options.parse_progression(p)
 					self.ui.progressions.addItem(p)
-
+				except:
+					pass
 
 	def get_options(self):
 		o = OptionClass()
